$set 3 #Configmenu

$ #ConfigOptions
# Belltsok
$ #FocusModel
# Fkusz modell
$ #WindowPlacement
# Ablakok elhelyezse
$ #ImageDithering
# Image dithering
$ #OpaqueMove
# tltsz ablakok mozgats kzben
$ #FullMax
# Teljeskpernys maximalizls
$ #FocusNew
# j ablak kapja a fkuszt
$ #FocusLast
# Munkaasztal vltsa utn fkusz az utols ablakon
$ #DisableBindings
# Scroll Lock-nl nem figyeli a billentyzetet
$ #ClickToFocus
# Kattints fkuszhoz
$ #SloppyFocus
# A fkusz kveti az egeret
$ #AutoRaise
# Autmatikus elreugr ablakok
$ #ClickRaise
# Kattintssal az eltrbe
$ #SmartRows
# Optimlis ablakrendezs (sorok)
$ #SmartCols
# Optimlis ablakrendezs (oszlopok)
$ #Cascade
# Egymsracssztatott elrendezs
$ #LeftRight
# Jobbrl balra
$ #RightLeft
# Balrl jobbra
$ #TopBottom
# Fentrl lefele
$ #BottomTop
# Lentrl felfele
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
